@@ -16,12 +16,19 @@ test_that("MASS::glm.nb tidier arguments", {
 test_that("tidy.negbin", {
   td1 <- tidy(fit)
   td2 <- tidy(fit, conf.int = TRUE)
+  td3 <- tidy(fit, exponentiate = TRUE, conf.int = TRUE)
   
   check_tidy_output(td2)
   check_tidy_output(td1)
   
   expect_false(NA %in% td2$conf.low)
   expect_false(NA %in% td2$conf.high)
+  
+  # exponentiate arg check
+  expect_equal(
+    as.matrix(td3[, c("estimate", "conf.low", "conf.high")]),
+    exp(as.matrix(td2[, c("estimate", "conf.low", "conf.high")]))
+  )
 })
 
 test_that("glance.negbin", {
@@ -29,5 +36,3 @@ test_that("glance.negbin", {
   check_glance_outputs(gl)
   check_dims(gl, 1, 8)
 })
-
-
